//@line 4 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/comm-beta/calendar/locales/en-US/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/comm-beta/calendar/locales/en-US/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/comm-beta/calendar/locales/en-US/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 12 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/comm-beta/calendar/locales/en-US/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "hsb");

//@line 23 "/builds/slave/tb-rel-c-beta-l64_rpk_5-000000/comm-beta/calendar/locales/en-US/lightning-l10n.js"
pref("calendar.categories.names", "Anniversary,Birthday,Business,Calls,Clients,Competition,Customer,Favorites,Follow up,Gifts,Holidays,Ideas,Issues,Meeting,Miscellaneous,Personal,Projects,Public Holiday,Status,Suppliers,Travel,Vacation");
